//Change working directory: the directory must contain "coalitions_eu_data.dta"
//cd "CHANGE DIRECTORY"

//Load dataset
use "coalitions_eu_data.dta", clear



//////////////////////////
//Descriptive statistics
//////////////////////////

//Produce TABLE A2 in the Online Appendix 
estpost sum lr_position gov_lr_std_cmp gov_lr_std_range_cmp coordination oversight minority_gov lrs_lag6m eu_cont_gdp unemployment_wb inflation_wb regul_strength population if lr_position != .
esttab using Table_A2.rtf, replace cells("mean(fmt(2)) sd(fmt(2)) min(fmt(2)) max(fmt(2))") nomtitle nonumber label

//Produce TABLE A3 in the Online Appendix
estpost tab government if lr_position != ., sort
esttab using Table_A3.rtf, append cells("b pct(fmt(2)) cumpct(fmt(2))") nomtitle nonumber label

//Produce TABLE A4 in the Online Appendix
//Ideological divisiveness
estpost tabstat gov_lr_std_range_cmp if lr_position != ., by(government)
esttab using Table_A4.rtf, append cells("mean(fmt(2))") nomtitle nonumber label
//Executive coordination
estpost tabstat coordination if lr_position != ., by(government)
esttab using Table_A4.rtf, append cells("mean(fmt(2))") nomtitle nonumber label
//Parliamentary oversight
estpost tabstat oversight if lr_position != ., by(government)
esttab using Table_A4.rtf, append cells("mean(fmt(2))") nomtitle nonumber label
//Minority government
estpost tabstat minority_gov if lr_position != ., by(government)
esttab using Table_A4.rtf, append cells("mean(fmt(2))") nomtitle nonumber label

//Report extent of missing data in TABLE 5 in the Online Appendix
mdesc lr_position gov_lr_std_cmp gov_lr_std_range_cmp coordination oversight minority_gov lrs_lag6m eu_cont_gdp unemployment_wb inflation_wb regul_strength population


///////////////
//Main models
//////////////

//Estimate results in TABLE 1 in the article
xtset n_issue
reg lr_position c.gov_lr_std_range_cmp##c.gov_lr_std_cmp coordination##c.gov_lr_std_cmp minority_gov##c.oversight##c.gov_lr_std_cmp lrs_lag6m eu_cont_gdp unemployment_wb inflation_wb regul_strength population i.n_issue, vce(cluster country)
xtreg lr_position c.gov_lr_std_range_cmp##c.gov_lr_std_cmp coordination##c.gov_lr_std_cmp minority_gov##c.oversight##c.gov_lr_std_cmp lrs_lag6m eu_cont_gdp unemployment_wb inflation_wb regul_strength population, fe vce(cluster country) nonest dfadj
outreg using "Table_1.doc", replace starlevels(5 1) se

//Assess linear combination of two-way and three-way coefficient (see footnote 12 in the article)
lincom 1.minority_gov#c.oversight#c.gov_lr_std_cmp + c.oversight#c.gov_lr_std_cmp

//Scenario effect sizes (mentioned in results section of the article)
margins, dydx(gov_lr_std_cmp) at(coordination = (0 1) minority_gov = 0) 
margins, dydx(gov_lr_std_cmp) at(coordination = (1) minority_gov = 0 oversight = (0.6 1.25)) 
margins, dydx(gov_lr_std_cmp) at(coordination = 1 minority_gov = 1) 
margins, dydx(gov_lr_std_cmp) at(coordination = 1 minority_gov = 1 oversight = (1.25)) 
margins, dydx(gov_lr_std_cmp) at(coordination = 0 minority_gov = 1 oversight = (1.50)) 

//Produce FIGURE 3 in the article
margins, dydx(gov_lr_std_cmp) at(gov_lr_std_range_cmp = (0 (5) 70)) 
mat a = r(table)'
svmat a, name(col)
mat at = r(at)
svmat at, name(col2)
twoway (histogram gov_lr_std_range_cmp if e(sample) == 1, bin(20) scheme(lean2) yaxis(1) yscale(axis(1) alt) legend(off) fcolor(gs12) lcolor(gs12) frequency ylabel(, nogrid)) (line b col21, yaxis(2) yscale(axis(2) alt noline) ytitle("Number of observations") ytitle("Marginal effect of {it:compromise position}", axis(2)) lpattern(solid)) (line ll col21, yaxis(2) lpattern(dash)) (line ul col21, yaxis(2) lpattern(dash)) (function y=0, range(0 70) lcolor(gs8) lpattern(solid) yaxis(2)), xtitle("{it:Ideological divisiveness} of support coalition") xscale(range(-3 73) noextend) xlabel(0 (10) 70)  yscale(noline) xscale(noline)
graph save "Figure_3", replace
graph export "Figure_3.png", replace height(1500)
graph export "Figure_3.tif", replace height(1500)
drop b se z pvalue ll ul df crit eform col2*

//Produce FIGURE 4 in the article
margins, dydx(gov_lr_std_cmp) at(oversight = (0.2 (0.1) 1.4) coordination = (0) minority_gov = (0))
mat a = r(table)'
svmat a, name(col)
mat at = r(at)
svmat at, name(col2)
twoway (histogram oversight if minority_gov == 0 & coordination == 0 & e(sample) == 1, bin(20) scheme(lean2) yaxis(1) yscale(axis(1) alt off) xlabel(,labsize(large)) legend(off) fcolor(gs12) lcolor(gs12) frequency ylabel(, nogrid)) (line b col27, yaxis(2) ylabel(, axis(2) labsize(large)) yscale(axis(2) alt noline) ytitle("") ytitle("Marginal effect of {it:compromise position}", size("large") axis(2)) lpattern(solid)) (line ll col27, yaxis(2) lpattern(dash)) (line ul col27, yaxis(2) lpattern(dash)) (function y=0, range(0.20 1.4) lcolor(gs8) lpattern(solid) yaxis(2)), xtitle("") xscale(range(0.20 1.40) noextend) xlabel(0.20 (0.2) 1.40)  yscale(noline) xscale(noline) title("{bf:No executive coordination (n=750)}")
graph save "coordination_0_mingov_0.gph", replace
drop b se z pvalue ll ul df crit eform col2*

margins, dydx(gov_lr_std_cmp) at(oversight = (0.2 (0.1) 1.8) coordination = (1) minority_gov = (0))
mat a = r(table)'
svmat a, name(col)
mat at = r(at)
svmat at, name(col2)
twoway (histogram oversight if minority_gov == 0 & coordination == 1 & e(sample) == 1, bin(20) scheme(lean2) yaxis(1) yscale(axis(1) alt) xlabel(,labsize(large)) legend(off) fcolor(gs12) lcolor(gs12) frequency ylabel(, nogrid)) (line b col27, yaxis(2) ylabel(, axis(1) labsize(large)) yscale(axis(2) alt off) ytitle("Number of observations", size("large")) ytitle("", axis(2)) lpattern(solid)) (line ll col27, yaxis(2) lpattern(dash)) (line ul col27, yaxis(2) lpattern(dash)) (function y=0, range(0.20 1.8) lcolor(gs8) lpattern(solid) yaxis(2)), xtitle("") xscale(range(0.20 1.80) noextend) xlabel(0.20 (0.2) 1.80)  yscale(noline) xscale(noline) title("{bf:Executive coordination (n=599)}")
graph save "coordination_1_mingov_0.gph", replace
drop b se z pvalue ll ul df crit eform col2*

margins, dydx(gov_lr_std_cmp) at(oversight = (0.4 (0.1) 1.4) coordination = (0) minority_gov = (1))
mat a = r(table)'
svmat a, name(col)
mat at = r(at)
svmat at, name(col2)
twoway (histogram oversight if minority_gov == 1 & coordination == 0 & e(sample) == 1, bin(20) scheme(lean2) yaxis(1) yscale(axis(1) alt off) xlabel(,labsize(large)) legend(off) fcolor(gs12) lcolor(gs12) frequency ylabel(, nogrid)) (line b col27, yaxis(2) ylabel(, axis(2) labsize(large)) yscale(axis(2) alt noline) ytitle("") ytitle("Marginal effect of {it:compromise position}", size("large") axis(2)) lpattern(solid)) (line ll col27, yaxis(2) lpattern(dash)) (line ul col27, yaxis(2) lpattern(dash)) (function y=0, range(0.40 1.4) lcolor(gs8) lpattern(solid) yaxis(2)), xtitle("") xscale(range(0.40 1.40) noextend) xlabel(0.40 (0.2) 1.40)  yscale(noline) xscale(noline) title("{bf:No executive coordination (n=97)}")
graph save "coordination_0_mingov_1.gph", replace
drop b se z pvalue ll ul df crit eform col2*

margins, dydx(gov_lr_std_cmp) at(oversight = (0.2 (0.1) 1.8) coordination = (1) minority_gov = (1))
mat a = r(table)'
svmat a, name(col)
mat at = r(at)
svmat at, name(col2)
twoway (histogram oversight if minority_gov == 1 & coordination == 1 & e(sample) == 1, bin(20) scheme(lean2) yaxis(1) yscale(axis(1) alt) xlabel(,labsize(large)) legend(off) fcolor(gs12) lcolor(gs12) frequency ylabel(, nogrid)) (line b col27, yaxis(2) ylabel(, axis(1) labsize(large)) yscale(axis(2) alt off) ytitle("Number of observations", size("large")) ytitle("", axis(2)) lpattern(solid)) (line ll col27, yaxis(2) lpattern(dash)) (line ul col27, yaxis(2) lpattern(dash)) (function y=0, range(0.20 1.8) lcolor(gs8) lpattern(solid) yaxis(2)), xtitle("") xscale(range(0.20 1.80) noextend) xlabel(0.20 (0.2) 1.80)  yscale(noline) xscale(noline) title("{bf:Executive coordination (n=248)}")
graph save "coordination_1_mingov_1.gph", replace
drop b se z pvalue ll ul df crit eform col2*

//Report cases where marginal effect of the compromise is (in)significant - mentioned in the results section of the paper
tab government if e(sample) == 1 & oversight > 1.32 & coordination == 1 & minority_gov == 0
tab government if e(sample) == 1 & oversight > 1.24 & coordination == 1 & minority_gov == 1

graph combine "coordination_0_mingov_0.gph" "coordination_1_mingov_0.gph", ycommon scheme(lean2) altshrink title("{bf:a) Majority governments}", size("medium")) b1title("Strength of {it:parliamentary oversight}", size("medsmall"))
graph save "marginal_effects_majority", replace
graph export "marginal_effects_majority.png", replace height(2000)

graph combine "coordination_0_mingov_1.gph" "coordination_1_mingov_1.gph", ycommon scheme(lean2) altshrink title("{bf:b) Minority governments}", size("medium")) b1title("Strength of {it:parliamentary oversight}", size("medsmall"))
graph save "marginal_effects_minority", replace
graph export "marginal_effects_minority.png", replace height(2000)

graph combine "marginal_effects_majority.gph" "marginal_effects_minority.gph", scheme(lean2) altshrink col(1) ysize(2.97) xsize(2.10)
graph save "Figure_4", replace
graph export "Figure_4.png", replace height(2000)
graph export "Figure_4.tif", replace height(2000)



//////////////////////////////////////////////////////////
//Monte Carlo Simulations to Validate Empirical Strategy
//////////////////////////////////////////////////////////

//Define simulations as described in section 7) of the Online Appendix

program party_sim, rclass
version 13
drop _all

//Set number of observations and issues
set obs 2000
gen issue = int((_n-1)/25) + 1
gen cabinet = int((_n-1)/500) + 1
gen country = mod(_n-1,25) + 1

//Draw RILE positions and seat distribution
gen party1_RILE = rnormal(0, 10)
sort country cabinet issue
by country cabinet: replace party1_RILE = party1_RILE[1]
gen party2_RILE = rnormal(0, 10)
by country cabinet: replace party2_RILE = party2_RILE[1]
gen party1_seats = runiform(0.1, 0.9)
gen party2_seats = 1 - party1_seats

//Calculate compromise on RILE scale
gen compromise = party1_seats * party1_RILE + party2_seats * party2_RILE

//Draw the degree of compromise (i.e. partial) and party of minister
gen compromise_autonomy = runiform()
gen minister_party1 = rbinomial(1, party1_seats)

//Draw compromise measurement
gen compromise_measured = compromise_autonomy > 0.5

//Insert DEU position
gen DEU_position = .
replace DEU_position = compromise_autonomy * compromise + (1 - compromise_autonomy) * party1_RILE if minister_party1 == 1
replace DEU_position = compromise_autonomy * compromise + (1 - compromise_autonomy) * party2_RILE if minister_party1 == 0

//Rescale DEU position
egen min_DEU = min(DEU_position), by(issue)
egen max_DEU = max(DEU_position), by(issue)
replace DEU_position = (DEU_position - min_DEU)/(max_DEU - min_DEU) * 100

//Draw cut-points
gen cut1 = runiform(25, 75)
sort issue country cabinet
by issue: replace cut1 = cut1[1]
gen cut2 = runiform(25, 75)
by issue: replace cut2 = cut2[1]

//Classify DEU position
replace DEU_position = 0 if DEU_position < cut1 & cut1 < cut2
replace DEU_position = 0 if DEU_position < cut2 & cut1 > cut2

replace DEU_position = 50 if DEU_position > cut1 & DEU_position < cut2 & cut1 < cut2
replace DEU_position = 50 if DEU_position > cut2 & DEU_position < cut1 & cut1 > cut2

replace DEU_position = 100 if DEU_position > cut2 & cut1 < cut2
replace DEU_position = 100 if DEU_position > cut1 & cut1 > cut2

//Estimate model
xtset issue
xtreg DEU_position compromise_measured##c.compromise, fe vce(cluster country) nonest dfadj

end

//Run 10,000 simulations
simulate _b _se, reps(10000) seed(123456): party_sim
save "simulations.dta", replace

//Produce FIGURE A1 in the Online Appendix
gen t_statistic = _sim_5/_sim_11
histogram t_statistic, xtitle("t-statistic of coefficient on interaction term") scheme(lean2)
graph save "Figure_A1", replace
graph export "Figure_A1.png", replace height(1500)
graph export "Figure_A1.tif", replace height(1500)

//Report how many statistics are >0 and >2, mentioned in section 7) in the Online Appendix
sum t_statistic if t_statistic > 0
sum t_statistic if t_statistic > 2



/////////////////////
//Robustness Checks
/////////////////////

//Load dataset and set fixed effects
use "coalitions_eu_data.dta", clear
xtset n_issue 

//Estimate MODEL 1 in Table A7: Compromise position that is simple average of all participating parties
xtreg lr_position c.gov_lr_std_range_cmp##c.gov_uw_std_cmp coordination##c.gov_uw_std_cmp minority_gov##c.oversight##c.gov_uw_std_cmp lrs_lag6m eu_cont_gdp unemployment_wb inflation_wb regul_strength population, fe vce(cluster country) nonest dfadj
outreg using "Table_A7", replace starlevels(10 5 1) se
lincom 1.minority_gov#c.oversight#c.gov_uw_std_cmp + c.oversight#c.gov_uw_std_cmp

//Estimate MODEL 2 in Table A7: Compromise position that is seat-weighted average of all participating parties including party closest to PM
xtreg lr_position c.gov_PM_lr_std_range_cmp##c.gov_PM_lr_std_cmp coordination##c.gov_PM_lr_std_cmp minority_gov##c.oversight##c.gov_PM_lr_std_cmp lrs_lag6m eu_cont_gdp unemployment_wb inflation_wb regul_strength population, fe vce(cluster country) nonest dfadj
outreg using "Table_A7", merge starlevels(10 5 1) se
lincom 1.minority_gov#c.oversight#c.gov_PM_lr_std_cmp + c.oversight#c.gov_PM_lr_std_cmp

//Estimate MODEL 3 in Table A7: Divisiveness measure as maximum distance to largest party
xtreg lr_position c.gov_divisiveness_max_dis##c.gov_lr_std_cmp coordination##c.gov_lr_std_cmp minority_gov##c.oversight##c.gov_lr_std_cmp lrs_lag6m eu_cont_gdp unemployment_wb inflation_wb regul_strength population, fe vce(cluster country) nonest dfadj
outreg using "Table_A7", merge starlevels(10 5 1) se
lincom 1.minority_gov#c.oversight#c.gov_lr_std_cmp + c.oversight#c.gov_lr_std_cmp

//Estimate MODEL 4 in Table A7: Divisiveness measure as summed distance to largest party
xtreg lr_position c.gov_divisiveness_sum_dis##c.gov_lr_std_cmp coordination##c.gov_lr_std_cmp minority_gov##c.oversight##c.gov_lr_std_cmp lrs_lag6m eu_cont_gdp unemployment_wb inflation_wb regul_strength population, fe vce(cluster country) nonest dfadj
outreg using "Table_A7", merge starlevels(10 5 1) se
lincom 1.minority_gov#c.oversight#c.gov_lr_std_cmp + c.oversight#c.gov_lr_std_cmp

//Estimate MODEL 5 in Table A7: Western Europe only
xtreg lr_position c.gov_lr_std_range_cmp##c.gov_lr_std_cmp coordination##c.gov_lr_std_cmp minority_gov##c.oversight##c.gov_lr_std_cmp lrs_lag6m eu_cont_gdp unemployment_wb inflation_wb regul_strength population if post_com == 0, fe vce(robust) 
outreg using "Table_A7", merge starlevels(10 5 1) se
lincom 1.minority_gov#c.oversight#c.gov_lr_std_cmp + c.oversight#c.gov_lr_std_cmp

//Estimate MODEL 6 in Table A7: Binary dependent variable
logit lr_position_binary c.gov_lr_std_range_cmp##c.gov_lr_std_cmp coordination##c.gov_lr_std_cmp minority_gov##c.oversight##c.gov_lr_std_cmp lrs_lag6m eu_cont_gdp unemployment_wb inflation_wb regul_strength population i.n_issue, vce(cluster country) 
outreg using "Table_A7", merge starlevels(10 5 1) se
lincom 1.minority_gov#c.oversight#c.gov_lr_std_cmp + c.oversight#c.gov_lr_std_cmp

//Estimate MODEL 7 in Table A7: Multiple imputation
//Create interactions passively
xtset country
gen int_range = gov_lr_std_range_cmp * gov_lr_std_cmp
gen int_coordination = coordination * gov_lr_std_cmp
gen int_minority = minority_gov * gov_lr_std_cmp
gen int_oversight = oversight * gov_lr_std_cmp
gen int_minority_oversight = minority_gov * oversight * gov_lr_std_cmp
gen minority_oversight = oversight * minority_gov
//Start multiple imputations using chained equations
set seed 12345
mi set flong
mi register imputed gov_lr_std_range_cmp oversight minority_oversight int_range int_coordination int_minority int_oversight int_minority_oversight gov_lr_std_cmp
mi impute chained (reg) gov_lr_std_range_cmp oversight minority_oversight int_range int_coordination int_minority int_oversight int_minority_oversight gov_lr_std_cmp = no_families i.n_issue lr_position_MI coordination minority_gov lrs_lag6m eu_cont_gdp unemployment_wb inflation_wb regul_strength population, add(10) force

//Perform MI analysis
mi xtset n_issue
mi estimate, post: xtreg lr_position_MI gov_lr_std_cmp gov_lr_std_range_cmp int_range coordination int_coordination minority_gov oversight minority_oversight int_minority int_oversight int_minority_oversight lrs_lag6m eu_cont_gdp unemployment_wb inflation_wb regul_strength population, fe vce(cluster country) nonest dfadj
outreg using "Table_A7", merge starlevels(10 5 1) se
lincom int_minority_oversight + int_oversight



////////////////////////////////////////////////////
//Comparison to Results of Martin & Vanberg (2011)
////////////////////////////////////////////////////

//Load dataset
use "coalitions_eu_data.dta", clear

//Create indicator for Martin & Vanberg (2011) country sample
gen mv_sample = 0
replace mv_sample = 1 if (government == "de" | government == "fr" | government == "dk" | government == "ie" | government == "nl")

//Estimate results in TABLE A8 in the Online Appendix
xtset n_issue
reg lr_position c.gov_lr_std_range_cmp##c.gov_lr_std_cmp coordination##c.gov_lr_std_cmp mv_sample##c.oversight##c.gov_lr_std_cmp lrs_lag6m eu_cont_gdp unemployment_wb inflation_wb regul_strength population i.n_issue, vce(cluster country)
xtreg lr_position c.gov_lr_std_range_cmp##c.gov_lr_std_cmp coordination##c.gov_lr_std_cmp mv_sample##c.oversight##c.gov_lr_std_cmp lrs_lag6m eu_cont_gdp unemployment_wb inflation_wb regul_strength population, fe vce(cluster country) nonest dfadj
outreg using "Table_A8.doc", replace starlevels(10 5 1) se

//Produce FIGURE A3 in the Online Appendix
margins, dydx(gov_lr_std_cmp) at(oversight = (0.2 (0.1) 1.8) mv_sample = (0))
mat a = r(table)'
svmat a, name(col)
mat at = r(at)
svmat at, name(col2)
twoway (histogram oversight if mv_sample == 0 & e(sample) == 1, bin(20) scheme(lean2) yaxis(1) yscale(axis(1) alt off) legend(off) fcolor(gs12) lcolor(gs12) frequency ylabel(, nogrid)) (line b col27, yaxis(2) yscale(axis(2) alt noline) ytitle("") ytitle("Marginal effect of {it:compromise position}", size("medium") axis(2)) lpattern(solid)) (line ll col27, yaxis(2) lpattern(dash)) (line ul col27, yaxis(2) lpattern(dash)) (function y=0, range(0.20 1.8) lcolor(gs8) lpattern(solid) yaxis(2)), xtitle("") xscale(range(0.20 1.80) noextend) xlabel(0.20 (0.2) 1.80)  yscale(noline) xscale(noline) title("{bf:Countries NOT in M&V (n=1016)}", size("large"))
graph save "mv_sample_0.gph", replace
drop b se z pvalue ll ul df crit eform col2*

margins, dydx(gov_lr_std_cmp) at(oversight = (0.2 (0.1) 1.8) mv_sample = (1))
mat a = r(table)'
svmat a, name(col)
mat at = r(at)
svmat at, name(col2)
twoway (histogram oversight if mv_sample == 1 & e(sample) == 1, bin(20) scheme(lean2) yaxis(1) yscale(axis(1) alt) legend(off) fcolor(gs12) lcolor(gs12) frequency ylabel(, nogrid)) (line b col27, yaxis(2) yscale(axis(2) alt off) ytitle("Number of observations", size("medium")) ytitle("", axis(2)) lpattern(solid)) (line ll col27, yaxis(2) lpattern(dash)) (line ul col27, yaxis(2) lpattern(dash)) (function y=0, range(0.20 1.8) lcolor(gs8) lpattern(solid) yaxis(2)), xtitle("") xscale(range(0.20 1.80) noextend) xlabel(0.20 (0.2) 1.80)  yscale(noline) xscale(noline) title("{bf:Countries in M&V (n=678)}", size("large"))
graph save "mv_sample_1.gph", replace
drop b se z pvalue ll ul df crit eform col2*

graph combine "mv_sample_0.gph" "mv_sample_1.gph", ycommon xcommon scheme(lean2) row(1) altshrink b1("Strength of {it:parliamentary oversight}", size("small"))
graph save "Figure_A3", replace
graph export "Figure_A3.png", replace height(1500)
graph export "Figure_A3.tif", replace height(1500)



///////////////////////////////////////////////////////////////////
//Testing the Alternatives: Median Legislative Party and PM Party
///////////////////////////////////////////////////////////////////

//Create FIGURE A4 in the Online Appendix

//Testing against median legislative party
forvalues j = 0/9 {
xtreg lr_position gov_lr_std_cmp median_lr_std_cmp lrs_lag6m eu_cont_gdp unemployment_wb inflation_wb regul_strength population if abs(gov_lr_std_cmp - median_lr_std_cmp) > `j', fe vce(cluster country) nonest dfadj
estimates store m_`j'
corr gov_lr_std_cmp median_lr_std_cmp if e(sample) == 1
}
coefplot (m_0, label("> 0 ({it:.77})")) (m_3, label("> 3 ({it:.72})")) (m_5, label("> 5 ({it:.71})")) (m_7, label("> 7 ({it:.69})")) (m_9, label("> 9 ({it:.72})")), coeflabels(, labsize(medsmall)) xline(0, lcolor(gs10)) keep(gov_lr_std_cmp median_lr_std_cmp) rename(gov_lr_std_cmp = "{it:Compromise}" median_lr_std_cmp = "{it:Median / PM}") scheme(lean2) title("{bf:Compromise vs. median party's position}", size("medium")) legend(row(5) size(small) title("RILE distance ({it:correlation})" "compromise / median", size("small"))) xtitle("Coefficient", size("medsmall"))
graph save "median_compromise.gph", replace

//Testing against PM party
forvalues j = 0/12 {
xtreg lr_position gov_lr_std_cmp pm_lr_std_cmp lrs_lag6m eu_cont_gdp unemployment_wb inflation_wb regul_strength population if abs(gov_lr_std_cmp - pm_lr_std_cmp) > `j', fe vce(cluster country) nonest dfadj
estimates store m_`j'
corr gov_lr_std_cmp pm_lr_std_cmp if e(sample) == 1
}
coefplot (m_0, label("> 0 ({it:.74})")) (m_3, label("> 3 ({it:.68})")) (m_6, label("> 6 ({it:.63})")) (m_9, label("> 9 ({it:.58})")) (m_12, label("> 12 ({it:.60})")), coeflabels(, labsize(medsmall)) xline(0, lcolor(gs10)) keep(gov_lr_std_cmp pm_lr_std_cmp) scheme(lean2) title("{bf:Compromise vs. PM party's position}", size("medium")) yscale(off) legend(row(5) size(small) title("RILE distance ({it:correlation})" "compromise / PM", size("small"))) xtitle("Coefficient", size("medsmall"))
graph save "pm_compromise.gph", replace

graph combine "median_compromise.gph" "pm_compromise.gph", ycommon scheme(lean2) altshrink
graph save "Figure_A4", replace
graph export "Figure_A4.png", replace height(1500)
graph export "Figure_A4.tif", replace height(1500)


