rm(list = ls())  # clear

#Change working directory: this must contain "coalitions_eu_data.dta"
setwd("CHANGE")

install.packages("readstata13") #install packages if not already installed
install.packages("simex") 
require(readstata13) #require packages
require(simex)

#Load data and subset
data <- read.dta13("coalitions_eu_data.dta")
data$n_issue <- factor(data$n_issue)
is.factor(data$n_issue)
data <- data[!is.na(data$lr_position),]

#Run naive model assuming no measurement error
naive.model <- lm(lr_position ~ gov_lr_std_range_cmp * gov_lr_std_cmp + coordination * gov_lr_std_cmp + minority_gov * oversight * gov_lr_std_cmp + lrs_lag6m + eu_cont_gdp + unemployment_wb + inflation_wb + regul_strength + n_issue, data = data, x = TRUE)

#Define heteroskedastic measurement error and run SIMEX
set.seed(678910)
me <- as.vector(data$gov_lr_std_cmp_SE)
me2 <- as.vector(data$gov_lr_std_range_cmp_SE)
simex.model <- simex(model = naive.model, SIMEXvariable = c("gov_lr_std_cmp", "gov_lr_std_range_cmp"), measurement.error = cbind(me, me2), fitting.method = "quadratic", B = 500, asymptotic = FALSE)

#Summarise and plot models
summary(naive.model)
summary(simex.model)
plot(simex.model, ylab = "")
